# Python Vasculature BioMarker toolbox documentation

Official implementation, based on the work published by Fhima, Jonathan, Jan Van Eijgen, Ingeborg Stalmans, Yevgeniy Men, Moti Freiman, and Joachim A. Behar. “PVBM: A Python Vasculature Biomarker Toolbox Based on Retinal Blood Vessel Segmentation.” In Computer Vision–ECCV 2022 Workshops: Tel Aviv, Israel, October 23–27, 2022, Proceedings, Part III, pp. 296-312. Cham: Springer Nature Switzerland, 2023 (https://link.springer.com/chapter/10.1007/978-3-031-25066-8_15).
    
## Description

Eleven biomarkers can be engineered, namely: the area, length, perimeter, number of endpoints, number of intersection points, median tortuosity, median branching angle, capacity dimension, entropy dimension, correlation dimension and singularity length.

Installation

Available on pip. Run: "pip install pvbm"

pip project: https://pypi.org/project/pvbm/

read the docs: https://pvbm.readthedocs.io/en/latest/

github: https://github.com/aim-lab/PVBM


